% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/btest.R
\name{beh.test}
\alias{beh.test}
\title{Test for Behaviour Effects}
\usage{
beh.test(yobs, k = 5, nsamp = 10000)
}
\arguments{
\item{yobs}{The vector of observations - i.e. the order in which the
individuals were observed.}

\item{k}{The number of subsequent captures to consider. For example, if k=1,
we are only checking whether we capture the same individual twice in a row
(which closely resembles a runs test).}

\item{nsamp}{The number of replicate observation vectors to sample. Each replicate
observation vector produces a test statistic; the more test statistics, the more
reliable the test.}
}
\value{
Returns a list of length 3. The first entry is a scalar
  p-value for the data under model Mt. If this value is sufficiently small,
  a behaviour effects model (see \code{\link{fitMb}}) should be considered.
  The second entry is the test statistic for the observed data, and the third
  entry is the vector of test statistics for the replicates.
}
\description{
Undertakes the second model adequacy test proposed in the paper. It is a
permutation test, inspired by runs tests. This test measures whether
capturing an animal affects the probability of that animal being recaptured
in the following k captures. A failed test indicates that model Mb might be
appropriate.
}
\examples{
data(ypossum, package="ctime")  # Catlins possum data, included in the package
test = beh.test(ypossum)
test$P.Value    # p<0.001, strong evidence of behaviour effects
hist(test$T_rep,(min(test$T_rep)-0.5):(max(test$T_rep)+0.5),xlim = range(c(test$T_rep,test$T_obs)))
points(test$T_obs, 0, pch=4, lwd=5, cex=3, col="red")

}
\seealso{
\code{\link{het.test}} \code{\link{fitMb}}
}
