% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fitMb.R
\name{fitMb}
\alias{fitMb}
\title{Estimate Posterior Densities Under Model Mb}
\usage{
fitMb(yobs, madapt = 1000, mkeep = 10000, nchains = 3,
  phiprior = log(100)/log(3), removeadapt = TRUE, returnmcmc = TRUE)
}
\arguments{
\item{yobs}{The vector of observations - i.e. the order in which the individuals were observed.}

\item{madapt}{The number of adapting iterations to use in the MCMC updater.}

\item{mkeep}{The number of iterations to store from the MCMC updater.}

\item{nchains}{The number of concurrent Markov chains to construct.}

\item{phiprior}{The parameter for the Laplace prior on phi.}

\item{removeadapt}{A Boolean value. If true (the default), discard the first
\code{madapt} iterations in the chain as "burn-in".}

\item{returnmcmc}{A Boolean value. If true (the default), the returned
codafile is an mcmc list object, rather than an ordinary list.}
}
\value{
Returns either a list or an mcmc list. Each entry in the list is a
  coda containing the estimated posteriors for \code{N} and \code{phi}. There
  is one entry for each Markov chain constructed.
}
\description{
Use Gibbs sampling to estimate the posterior distributions for the true
number of individuals \code{N} and parameter \code{phi} under Mb. Mb allows
for a behavioural effect, where individuals might become more or less likely
to be recaptured once they are captured once. Note that this function takes
as input the vector of observations \code{y}, rather than the vector of
counts \code{c}.
}
\examples{
data(ypossum, package="ctime")  # Catlins possum data, included in the package
result = fitMb(ypossum)
plot(result)

}
\seealso{
\code{\link{beh.test}} \code{\link{fitMt}}
}
