% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fitMh.R
\name{fitMh}
\alias{fitMh}
\title{Estimate Posterior Densities Under Model Mh}
\usage{
fitMh(cobs, madapt = 1000, mkeep = 10000, nchains = 3,
  piprior = c(0.001, 0.001), rhoprior = -log(0.01), removeadapt = TRUE,
  returnmcmc = TRUE)
}
\arguments{
\item{cobs}{A vector of counts i.e. how many times each individual was
observed. This should exclude zeroes.}

\item{madapt}{The number of adapting iterations to use in the MCMC updater.}

\item{mkeep}{The number of iterations to store from the MCMC updater.}

\item{nchains}{The number of concurrent Markov chains to construct.}

\item{piprior}{The parameters for the Beta prior on pi.}

\item{rhoprior}{The parameter for the exponential prior on rho.}

\item{removeadapt}{A Boolean value. If true (the default), discard the first
\code{madapt} iterations in the chain as "burn-in".}

\item{returnmcmc}{A Boolean value. If true (the default), the returned
codafile is an mcmc list object, rather than an ordinary list.}
}
\value{
Returns either a list or an mcmc list. Each entry in the list is a
  coda containing the estimated posteriors for \code{N} as well as for
  \code{p} and \code{a}. There is one entry for each Markov chain
  constructed.
}
\description{
Use Gibbs sampling to estimate the posterior distribution for the true number
of individuals \code{N}, as well as posteriors for the hyperparameters for nu, denoted
\code{rho} and \code{pi}, under model Mh. Mh allows individual capture
probabilities to vary (heterogeneity).
}
\examples{
data(cimmigrant, package="ctime")  # Netherlands illegal immigrant counts (included in package)
result1 = fitMh(cimmigrant)
lattice::xyplot(result1)
summary(result1)

}
\seealso{
\code{\link{het.test}} \code{\link{fitMt}}
}
