% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fitMt.R
\name{fitMt}
\alias{fitMt}
\title{Estimate Posterior Densities Under Model Mt}
\usage{
fitMt(cobs, madapt = 1000, mkeep = 10000, nchains = 3,
  nuprior = c(0.001, 0.001), removeadapt = TRUE, returnmcmc = TRUE)
}
\arguments{
\item{cobs}{A vector of counts i.e. how many times each individual was
observed. This should exclude zeroes.}

\item{madapt}{The number of adapting iterations to use in the MCMC updater.}

\item{mkeep}{The number of iterations to store from the MCMC updater.}

\item{nchains}{The number of concurrent Markov chains to construct.}

\item{nuprior}{The parameters for the Gamma prior on nu.}

\item{removeadapt}{A Boolean value. If true (the default), discard the first
\code{madapt} iterations in the chain as "burn-in".}

\item{returnmcmc}{A Boolean value. If true (the default), the returned
codafile is an mcmc list object, rather than an ordinary list.}
}
\value{
Returns either a list or an mcmc list. Each entry in the list is a
  coda containing the estimated posteriors for \code{N} and\code{nu}. There
  is one entry for each Markov chain constructed.
}
\description{
Use Gibbs sampling to estimate the posterior distributions for the true
number of individuals \code{N} and associated parameter \code{nu} under model
Mt. Mt assumes equal detection probabilities for all individuals. This is
largely a redundant function since \code{\link{directMt}} calculates the
posterior for \code{N} directly.
}
\examples{
data(cbutterfly, package="ctime")  # Craig's butterfly counts (included in package)
result2 = fitMt(cbutterfly)
lattice::xyplot(result2)
summary(result2)

}
\seealso{
\code{\link{directMt}} \code{\link{het.test}} \code{\link{beh.test}}
}
