% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/htest.R
\name{het.test}
\alias{het.test}
\title{Test for Heterogeneity}
\usage{
het.test(Npost, cobs, nsamp = 5000)
}
\arguments{
\item{Npost}{The posterior distribution for the true number of individuals
\code{N} in the population, as an mx2 matrix. The second column lists
potential values of \code{N} and the first column gives the corresponding
densities. This will usually be output from \code{\link{directMt}}.}

\item{cobs}{The vector of counts i.e. how many times each individual was
observed. This should exclude zeroes.}

\item{nsamp}{The number of replicate count vectors to sample. Each replicate
count vector produces a test statistic; the more test statistics, the more
reliable the test.}
}
\value{
Returns a list of length 3. The first entry is a scalar p-value for
  the data under model Mt. If this value is sufficiently small, a
  heterogeneous model should be considered. The second entry is the test
  statistic for the observed data, and the third entry is the vector of test
  statistics for the replicates.
}
\description{
Undertakes the first model adequacy test proposed in the paper. It is a
posterior predictive assessment that tests for heterogeneity by measuring
whether the observed variability in counts is higher than would be expected
under homogeneity. A failed test indicates that model Mh might be
appropriate.
}
\examples{
data(cimmigrant, package="ctime")  # Netherlands illegal immigrant counts (included in package)
result = directMt(cimmigrant)
test = het.test(result$Posterior, cimmigrant)
test$p.value    # p close to zero, indicating heterogeneity
hist(test$W.rep,(min(test$W.rep)-0.5):(test$W.obs+0.5),xlim = range(c(test$W.rep,test$W.obs)))
points(test$W.obs, 0, pch=4, lwd=5, cex=3, col="red")

}
\seealso{
\code{\link{beh.test}} \code{\link{fitMh}}
}
